@@ -123,7 +123,7 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
       actual = arg_dict[name]
       subst = self._match_value_against_type(actual, formal, subst, view)
       if subst is None:
-        formal = self.vm.annotations_util.sub_one_annotation(
+        formal = self.vm.annotation_utils.sub_one_annotation(
             self._node, formal, [self._error_subst or {}])
 
         return None, function.BadParam(
@@ -283,10 +283,10 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
       # some sort of runtime processing of type annotations. We replace all type
       # parameters with 'object' so that they don't match concrete types like
       # 'int' but still match things like 'Any'.
-      type_params = self.vm.annotations_util.get_type_parameters(left)
+      type_params = self.vm.annotation_utils.get_type_parameters(left)
       obj_var = self.vm.convert.primitive_class_instances[object].to_variable(
           self._node)
-      left = self.vm.annotations_util.sub_one_annotation(
+      left = self.vm.annotation_utils.sub_one_annotation(
           self._node, left, [{p.full_name: obj_var for p in type_params}])
     assert not left.formal, left
 
@@ -424,7 +424,7 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
         # Since options without type parameters do not modify subst, we can
         # break after the first match rather than finding all matches. We still
         # need to fill in subst with *something* so that
-        # annotations_util.sub_one_annotation can tell that all annotations have
+        # annotation_utils.sub_one_annotation can tell that all annotations have
         # been fully matched.
         subst = self._subst_with_type_parameters_from(subst, other_type)
         break
@@ -456,7 +456,7 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
         isinstance(other_type, abstract.Empty)):
       return subst
     elif isinstance(left, abstract.AMBIGUOUS_OR_EMPTY):
-      params = self.vm.annotations_util.get_type_parameters(other_type)
+      params = self.vm.annotation_utils.get_type_parameters(other_type)
       if isinstance(left, abstract.Empty):
         value = self.vm.convert.empty
       else:
@@ -479,7 +479,7 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
       elif _is_callback_protocol(other_type):
         return self._match_type_against_callback_protocol(
             left, other_type, subst, view)
-      elif left.cls:
+      else:
         return self._match_instance_against_type(left, other_type, subst, view)
     elif isinstance(left, abstract.Module):
       if other_type.full_name in [
@@ -517,11 +517,9 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
       elif _is_callback_protocol(other_type):
         return self._match_type_against_callback_protocol(
             left, other_type, subst, view)
-      elif left.cls:
+      else:
         return self._match_type_against_type(
             abstract.Instance(left.cls, self.vm), other_type, subst, view)
-      else:
-        return None
     elif isinstance(left, dataclass_overlay.FieldInstance) and left.default:
       return self._match_all_bindings(left.default, other_type, subst, view)
     elif isinstance(left, abstract.SimpleValue):
@@ -590,7 +588,21 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
     return self._merge_substs(subst, [new_subst])
 
   def _get_param_matcher(self, callable_type):
-    """Helper for _match_signature_against_callable."""
+    """Helper for matching the parameters of a callable.
+
+    Args:
+      callable_type: The callable being matched against.
+
+    Returns:
+      A special param matcher: (left, right, subst) -> Optional[subst].
+        left: An argument to be matched against a parameter of callable_type.
+        right: A parameter of callable_type.
+        subst: The current substitution dictionary.
+      If the matcher returns a non-None subst dict, then the match has succeeded
+      via special matching rules for single TypeVars. Otherwise, the caller
+      should next attempt normal matching on the inputs. (See
+      _match_signature_against_callable for a usage example.)
+    """
     # Any type parameter should match an unconstrained, unbounded type parameter
     # that appears exactly once in a callable, in order for matching to succeed
     # in cases like:
@@ -601,12 +613,12 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
     # the callable must accept any argument, but here, it means that the
     # argument must be the same type as `x`.
     callable_param_count = collections.Counter(
-        self.vm.annotations_util.get_type_parameters(callable_type))
+        self.vm.annotation_utils.get_type_parameters(callable_type))
     if isinstance(callable_type, abstract.CallableClass):
       # In CallableClass, type parameters in arguments are double-counted
       # because ARGS contains the union of the individual arguments.
       callable_param_count.subtract(
-          self.vm.annotations_util.get_type_parameters(
+          self.vm.annotation_utils.get_type_parameters(
               callable_type.get_formal_type_parameter(abstract_utils.ARGS)))
     def match(left, right, subst):
       if (not isinstance(left, abstract.TypeParameter) or
@@ -720,11 +732,10 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
             left, other_type.formal_type_parameters[abstract_utils.T], subst,
             view)
     elif isinstance(other_type, class_mixin.Class):
-      if not self._satisfies_noniterable_str(left.get_class(), other_type):
-        self._noniterable_str_error = NonIterableStrError(left.get_class(),
-                                                          other_type)
+      if not self._satisfies_noniterable_str(left.cls, other_type):
+        self._noniterable_str_error = NonIterableStrError(left.cls, other_type)
         return None
-      base = self.match_from_mro(left.get_class(), other_type)
+      base = self.match_from_mro(left.cls, other_type)
       if base is None:
         if other_type.is_protocol:
           with self._track_partially_matched_protocols():
@@ -889,11 +900,17 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
       return subst
     if left.num_args != other_type.num_args:
       return None
+    param_match = self._get_param_matcher(other_type)
     for i in range(left.num_args):
-      # Flip actual and expected to enforce contravariance of argument types.
-      subst = self._instantiate_and_match(
-          other_type.formal_type_parameters[i], left.formal_type_parameters[i],
-          subst, view, container=other_type)
+      left_arg = left.formal_type_parameters[i]
+      right_arg = other_type.formal_type_parameters[i]
+      new_subst = param_match(left_arg, right_arg, subst)
+      if new_subst is None:
+        # Flip actual and expected to enforce contravariance of argument types.
+        subst = self._instantiate_and_match(
+            right_arg, left_arg, subst, view, container=other_type)
+      else:
+        subst = new_subst
       if subst is None:
         return None
     return subst
@@ -905,10 +922,8 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
       _ = left.items()  # loads all attributes into members
     if isinstance(left, abstract.SimpleValue):
       left_attributes.update(left.members)
-    left_cls = left.get_class()
-    if left_cls:
-      left_attributes.update(*(cls.get_own_attributes() for cls in left_cls.mro
-                               if isinstance(cls, class_mixin.Class)))
+    left_attributes.update(*(cls.get_own_attributes() for cls in left.cls.mro
+                             if isinstance(cls, class_mixin.Class)))
     if "__getitem__" in left_attributes and "__iter__" not in left_attributes:
       # If a class has a __getitem__ method, it also (implicitly) has a
       # __iter__: Python will emulate __iter__ by calling __getitem__ with
@@ -927,18 +942,17 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
     Returns:
       A new type parameter assignment if the matching succeeded, None otherwise.
     """
-    left_cls = left.get_class()
-    if isinstance(left_cls, abstract.AMBIGUOUS_OR_EMPTY):
+    if isinstance(left.cls, abstract.AMBIGUOUS_OR_EMPTY):
       return subst
-    elif left_cls.is_dynamic:
+    elif left.cls.is_dynamic:
       return self._subst_with_type_parameters_from(subst, other_type)
     left_attributes = self._get_attribute_names(left)
     missing = other_type.protocol_attributes - left_attributes
     if missing:  # not all protocol attributes are implemented by 'left'
       self._protocol_error = ProtocolMissingAttributesError(
-          left_cls, other_type, missing)
+          left.cls, other_type, missing)
       return None
-    key = (left_cls, other_type)
+    key = (left.cls, other_type)
     if key in self._protocol_cache:
       return subst
     self._protocol_cache.add(key)
@@ -980,9 +994,7 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
     return resolved_attribute
 
   def _get_type(self, value):
-    cls = value.get_class()
-    if not cls:
-      return None
+    cls = value.cls
     if (not isinstance(cls, (abstract.PyTDClass, abstract.InterpreterClass)) or
         not cls.template):
       return cls
@@ -1021,7 +1033,7 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
         for (param, value) in other_type.get_formal_type_parameters().items():
           annotation_subst[param] = value.instantiate(
               self._node, abstract_utils.DUMMY_CONTAINER)
-        callable_signature = self.vm.annotations_util.sub_one_annotation(
+        callable_signature = self.vm.annotation_utils.sub_one_annotation(
             self._node, callable_signature, [annotation_subst])
       yield callable_signature
 
@@ -1037,9 +1049,8 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
     Returns:
       A new type parameter assignment if the matching succeeded, None otherwise.
     """
-    left_cls = left.get_class()
     left_attribute = self._get_attribute_for_protocol_matching(
-        left_cls, attribute, left)
+        left.cls, attribute, left)
     if left_attribute is None:
       if attribute == "__iter__":
         # See _get_attribute_names: left has an implicit __iter__ method
@@ -1088,7 +1099,7 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
         # protocol_attribute_var.
         bad_left, bad_right = zip(*bad_matches)
         self._protocol_error = ProtocolTypeError(
-            left_cls, other_type, attribute, self.vm.merge_values(bad_left),
+            left.cls, other_type, attribute, self.vm.merge_values(bad_left),
             self.vm.merge_values(bad_right))
         return None
     return self._merge_substs(subst, new_substs)
@@ -1099,16 +1110,17 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
     # value altogether.
     concrete_values = []
     for v in values:
-      if not isinstance(v, (abstract.AMBIGUOUS_OR_EMPTY,
+      # TODO(b/200220895): This is probably wrong; we should expand unions
+      # instead of ignoring them.
+      if not isinstance(v, (abstract.AMBIGUOUS_OR_EMPTY, abstract.Union,
                             abstract.TypeParameterInstance)):
-        cls = v.get_class()
-        if not isinstance(cls, abstract.AMBIGUOUS_OR_EMPTY):
+        if not isinstance(v.cls, abstract.AMBIGUOUS_OR_EMPTY):
           concrete_values.append(v)
     return concrete_values
 
   def _satisfies_single_type(self, values):
     """Enforce that the variable contains only one concrete type."""
-    class_names = {v.get_class().full_name for v in values}
+    class_names = {v.cls.full_name for v in values}
     for compat_name, name in _COMPATIBLE_BUILTINS:
       if {compat_name, name} <= class_names:
         class_names.remove(compat_name)
@@ -1120,9 +1132,8 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
     common_classes = None
     object_in_values = False
     for v in values:
-      cls = v.get_class()
-      object_in_values |= cls == self.vm.convert.object_type
-      superclasses = {c.full_name for c in cls.mro}
+      object_in_values |= v.cls == self.vm.convert.object_type
+      superclasses = {c.full_name for c in v.cls.mro}
       for compat_name, name in _COMPATIBLE_BUILTINS:
         if compat_name in superclasses:
           superclasses.add(name)
@@ -1159,7 +1170,7 @@ class AbstractMatcher(utils.VirtualMachineWeakrefMixin):
 
   def _subst_with_type_parameters_from(self, subst, typ):
     subst = subst.copy()
-    for param in self.vm.annotations_util.get_type_parameters(typ):
+    for param in self.vm.annotation_utils.get_type_parameters(typ):
       if param.name not in subst:
         subst[param.name] = self.vm.convert.empty.to_variable(self._node)
     return subst
