@@ -11,8 +11,6 @@ from pytype import load_pytd
 from pytype import vm
 from pytype.tests import test_base
 
-import six
-
 import unittest
 
 
@@ -131,7 +129,7 @@ class MatcherTest(MatcherTestBase):
     var = self.vm.program.NewVariable()
     right = abstract.TypeParameter("T", self.vm)
     result = self.matcher.match_var_against_type(var, right, {}, {})
-    six.assertCountEqual(self, result.keys(), ["T"])
+    self.assertCountEqual(result.keys(), ["T"])
     self.assertFalse(result["T"].bindings)
 
   def test_empty_against_unsolvable(self):
@@ -303,7 +301,7 @@ class MatcherTest(MatcherTestBase):
 
   def test_bound_pytd_function_against_callable(self):
     instance = self._convert("""
-      class A(object):
+      class A:
         def f(self, x: int) -> bool: ...
     """, "A", as_instance=True)
     binding = instance.to_binding(self.vm.root_node)
@@ -383,14 +381,14 @@ class MatcherTest(MatcherTestBase):
     dummy_instance = abstract.Instance(self.vm.convert.tuple_type, self.vm)
     left = abstract.TypeParameterInstance(right, dummy_instance, self.vm)
     for result in self._match_var(left, right):
-      six.assertCountEqual(self,
-                           [(name, var.data) for name, var in result.items()],
-                           [("typing.AnyStr", [left])])
+      self.assertCountEqual(
+          [(name, var.data) for name, var in result.items()],
+          [("typing.AnyStr", [left])])
 
   def test_protocol(self):
     left1 = self._convert_type("str", as_instance=True)
     left2 = self._convert("""
-      class A(object):
+      class A:
         def lower(self) : ...
     """, "A", as_instance=True)
     left3 = self._convert_type("int", as_instance=True)
@@ -402,7 +400,7 @@ class MatcherTest(MatcherTestBase):
   def test_protocol_iterator(self):
     left1 = self._convert_type("Iterator", as_instance=True)
     left2 = self._convert("""
-      class A(object):
+      class A:
         def __next__(self): ...
         def __iter__(self): ...
     """, "A", as_instance=True)
@@ -415,7 +413,7 @@ class MatcherTest(MatcherTestBase):
   def test_protocol_sequence(self):
     left1 = self._convert_type("list", as_instance=True)
     left2 = self._convert("""
-      class A(object):
+      class A:
         def __getitem__(self, i) : ...
         def __len__(self): ...
     """, "A", as_instance=True)
@@ -429,7 +427,7 @@ class MatcherTest(MatcherTestBase):
   def test_parameterized_protocol(self):
     left1 = self._convert("""
       from typing import Iterator
-      class A(object):
+      class A:
         def __iter__(self) -> Iterator[int] : ...
     """, "A", as_instance=True)
     left2 = self._convert_type("int", as_instance=True)
