@@ -2083,18 +2083,6 @@ class PropertyDecoratorTest(_ParserTestBase):
           def name(self): ...
       """, 1, "@name.setter needs 2 param(s), got 1")
 
-    self.check_error("""
-      class A:
-          @name.foo
-          def name(self): ...
-      """, 1, "Unhandled decorator: name.foo")
-
-    self.check_error("""
-      class A:
-          @notname.deleter
-          def name(self): ...
-      """, 1, "Unhandled decorator: notname.deleter")
-
     self.check_error("""
       class A:
           @property
