@@ -1,20 +1,4 @@
-# -*- coding:utf-8; python-indent:2; indent-tabs-mode:nil -*-
-# Copyright 2013 Google Inc. All Rights Reserved.
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 """Utility classes for testing the PYTD parser."""
-from __future__ import print_function
 
 import os
 import sys
@@ -24,14 +8,13 @@ from pytype import load_pytd
 from pytype.pyi import parser
 from pytype.pytd import pytd_utils
 from pytype.pytd import visitors
-import six
-import unittest
+from pytype.tests import test_base
 
 
-class ParserTest(unittest.TestCase):
+class ParserTest(test_base.UnitTest):
   """Test utility class. Knows how to parse PYTD and compare source code."""
 
-  python_version = (2, 7)
+  loader: load_pytd.Loader
 
   @classmethod
   def setUpClass(cls):
@@ -54,16 +37,16 @@ class ParserTest(unittest.TestCase):
     ast = parser.parse_string(textwrap.dedent(src),
                               python_version=self.python_version)
     ast = ast.Visit(visitors.LookupExternalTypes(
-        {"__builtin__": self.loader.builtins, "typing": self.loader.typing}))
+        {"builtins": self.loader.builtins, "typing": self.loader.typing}))
     ast = ast.Visit(visitors.NamedTypeToClassType())
     ast = ast.Visit(visitors.AdjustTypeParameters())
     ast.Visit(visitors.FillInLocalPointers({
-        "": ast, "__builtin__": self.loader.builtins}))
+        "": ast, "builtins": self.loader.builtins}))
     ast.Visit(visitors.VerifyVisitor())
     return ast
 
   def ToAST(self, src_or_tree):
-    if isinstance(src_or_tree, six.string_types):
+    if isinstance(src_or_tree, str):
       # Put into a canonical form (removes comments, standard indents):
       return self.Parse(src_or_tree + "\n")
     else:  # isinstance(src_or_tree, tuple):
