@@ -7,7 +7,6 @@ from pytype.pytd import pytd_utils
 from pytype.pytd import serialize_ast
 from pytype.pytd import visitors
 from pytype.tests import test_base
-import six
 
 import unittest
 
@@ -35,7 +34,7 @@ class SerializeAstTest(test_base.UnitTest):
         x = List[int]
         b = List[int]
 
-        class SomeClass(object):
+        class SomeClass:
           def __init__(self, a: module2.ObjectMod2):
             pass
 
@@ -46,7 +45,7 @@ class SerializeAstTest(test_base.UnitTest):
     temp_dir.create_file("module2.pyi", """
         import queue
         def f() -> queue.Queue: ...
-        class ObjectMod2(object):
+        class ObjectMod2:
           def __init__(self):
             pass
     """)
@@ -88,8 +87,8 @@ class SerializeAstTest(test_base.UnitTest):
           serialized_ast.class_type_nodes)[1:])
       loaded_ast = serialize_ast.ProcessAst(serialized_ast, module_map)
 
-      with six.assertRaisesRegex(
-          self, ValueError, "Unresolved class: 'builtins.NoneType'"):
+      with self.assertRaisesRegex(
+          ValueError, "Unresolved class: 'builtins.NoneType'"):
         loaded_ast.Visit(visitors.VerifyLookup())
 
   def test_pickle(self):
@@ -103,8 +102,8 @@ class SerializeAstTest(test_base.UnitTest):
       with open(pickled_ast_filename, "rb") as fi:
         serialized_ast = pickle.load(fi)
       self.assertTrue(serialized_ast.ast)
-      six.assertCountEqual(
-          self, dict(serialized_ast.dependencies),
+      self.assertCountEqual(
+          dict(serialized_ast.dependencies),
           ["builtins", "foo.bar.module1", "module2", "queue"])
 
   def test_unrestorable_child(self):
@@ -142,7 +141,7 @@ class SerializeAstTest(test_base.UnitTest):
         import other_module
         x = other_module.UnusedReferenceNeededToKeepTheImport
 
-        class SomeClass(object):
+        class SomeClass:
           def __init__(will_be_replaced_with_visitor) -> None:
             pass
 
