@@ -90,16 +90,18 @@ class Typeshed:
   def _list_files(self, basedir):
     """Lists files recursively in a basedir relative to typeshed root."""
     if self._env_home:
-      return pytype_source_utils.list_files(os.path.join(self._root, basedir))
+      fs = pytype_source_utils.list_files(os.path.join(self._root, basedir))
     else:
-      return pytype_source_utils.list_pytype_files(
+      fs = pytype_source_utils.list_pytype_files(
           os.path.join("typeshed", basedir))
+    return [f for f in fs if "@python2" not in f]
 
   def _load_missing(self):
     if not self.MISSING_FILE:
       return set()
     _, text = self._load_file(self.MISSING_FILE)
-    return {line.strip() for line in text.split("\n") if line}
+    return {line.strip() for line in text.split("\n")
+            if line and "@python2" not in line}
 
   def _load_stdlib_versions(self):
     """Loads the contents of typeshed/stdlib/VERSIONS.
@@ -109,13 +111,9 @@ class Typeshed:
     `{module}: {min_major}.{min_minor}-{max_major}.{max_minor}`.
 
     Returns:
-      A mapping from module name to ((min_major, min_minor),
-      (max_major, max_minor), use_python2) Python version.
-      The max tuple can be `None`. The use_python2 member indicates
-      whether stubs are present in the @python2 directory. If so,
-      stubs outside @python2 should not be used. This is relevant
-      if a package contains more files in Python 3 than it did in
-      Python 2.
+      A mapping from module name to version range in the format
+        {name: ((min_major, min_minor), (max_major, max_minor))}
+      The max tuple can be `None`.
     """
     _, text = self._load_file(os.path.join("stdlib", "VERSIONS"))
     versions = {}
@@ -123,20 +121,14 @@ class Typeshed:
       line2 = line.split("#")[0].strip()
       if not line2:
         continue
-      match = re.fullmatch(r"(.+): (\d)\.(\d+)(?:-(?:(\d)\.(\d))?)?", line2)
+      match = re.fullmatch(r"(.+): (\d)\.(\d+)(?:-(?:(\d)\.(\d+))?)?", line2)
       assert match
       module, min_major, min_minor, max_major, max_minor = match.groups()
       minimum = (int(min_major), int(min_minor))
       maximum = ((int(max_major), int(max_minor))
                  if max_major is not None and max_minor is not None
                  else None)
-      versions[module] = minimum, maximum, False
-    for path in self._list_files(os.path.join("stdlib", "@python2")):
-      mod, _ = os.path.splitext(path.split(os.path.sep, 1)[0])
-      if mod in versions:
-        (min_major, min_minor), maximum, _ = versions[mod]
-        if min_major == 2:
-          versions[mod] = (min_major, min_minor), maximum, True
+      versions[module] = minimum, maximum
     return versions
 
   def _load_third_party_packages(self):
@@ -148,43 +140,33 @@ class Typeshed:
     it will either have separate stubs in a @python2 subdirectory or
     the `python2 = true` flag is set in METADATA.toml. If a package supports
     Python 3, it will have at least one module or package on the top level
-    and the `python3 = false` flag is not set in METADATA.toml.
+    and the `python3 = false` flag is not set in METADATA.toml. Finally, the
+    top-level directory may contain a @tests subdirectory for typeshed testing.
 
     Returns:
-      A mapping from module name to a set of
-      (package name, major_python_version) tuples.
+      A mapping from module name to a set of package names.
     """
     modules = collections.defaultdict(set)
-    py2_dir = set()  # packages with @python2 directory
-    py2_meta = set()  # packages with `python2 = true` metadata entry
     top_level_stubs = set()  # packages with stub files outside @python2
     no_py3_meta = set()  # packages with `python3 = false` metadata entry
     for third_party_file in self._list_files("stubs"):
       parts = third_party_file.split(os.path.sep)
       if parts[-1] == "METADATA.toml":  # {package}/METADATA.toml
-        _, metadata_file = self._load_file(
-            os.path.join("stubs", third_party_file))
-        metadata = toml.loads(metadata_file)
-        if metadata.get("python2", False):
-          py2_meta.add(parts[0])
+        _, md_file = self._load_file(os.path.join("stubs", third_party_file))
+        metadata = toml.loads(md_file)
         if not metadata.get("python3", True):
           no_py3_meta.add(parts[0])
-      elif "@python2" in parts:  # {package}/@python2/{module}
-        py2_dir.add(parts[0])
-        name, _ = os.path.splitext(parts[2])
-        modules[parts[0]].add(name)
-      elif "@python2" not in parts:  # {package}/{module}
+      elif parts[1] != "@tests":  # {package}/{module}[/{submodule}]
         if parts[-1].endswith(".pyi"):
           top_level_stubs.add(parts[0])
         name, _ = os.path.splitext(parts[1])
         modules[parts[0]].add(name)
+    py3_stubs = top_level_stubs - no_py3_meta
     packages = collections.defaultdict(set)
     for package, names in modules.items():
       for name in names:
-        if package in py2_dir or package in py2_meta:
-          packages[name].add((package, 2))
-        if package in top_level_stubs and package not in no_py3_meta:
-          packages[name].add((package, 3))
+        if package in py3_stubs:
+          packages[name].add(package)
     return packages
 
   @property
@@ -202,14 +184,6 @@ class Typeshed:
     """
     return self._root
 
-  def _ignore(self, module, version):
-    """Return True if we ignore a file in typeshed."""
-    if module == "builtins" and version[0] == 2:
-      # The Python 2 version of "builtin" is a mypy artifact. This module
-      # doesn't actually exist, in Python 2.7.
-      return True
-    return False
-
   def get_module_file(self, toplevel, module, version):
     """Get the contents of a typeshed .pyi file.
 
@@ -231,13 +205,10 @@ class Typeshed:
     module_path = os.path.join(*module_parts)
     paths = []
     if toplevel == "stdlib":
-      # stubs for the stdlib 'foo' module are located in either stdlib/foo or
-      # (for Python 2) stdlib/@python2/foo. The VERSIONS file tells us whether
-      # stdlib/foo exists and what versions it targets; we always have to check
-      # @python2 first for Python 2 stubs.
+      # Stubs for the stdlib 'foo' module are located in stdlib/foo.
+      # The VERSIONS file tells us whether stdlib/foo exists and what versions
+      # it targets.
       path = os.path.join(toplevel, module_path)
-      if version[0] == 2:
-        paths.append(os.path.join(toplevel, "@python2", module_path))
       if (self._is_module_in_typeshed(module_parts, version) or
           path in self.missing):
         paths.append(path)
@@ -246,16 +217,8 @@ class Typeshed:
       # provides a module with the specified name in the right version.
       # TODO(rechen): It would be more correct to check what packages are
       # currently installed and only consider those.
-      if module_parts[0] in self._third_party_packages:
-        for package, v in sorted(self._third_party_packages[module_parts[0]]):
-          if v == version[0]:
-            if v == 2:
-              # In packages that support Python 2, if @python2/ exists, then it
-              # contains the Python 2 stubs; otherwise, the top-level stubs are
-              # Python 2and3.
-              paths.append(
-                  os.path.join("stubs", package, "@python2", module_path))
-            paths.append(os.path.join("stubs", package, module_path))
+      for package in sorted(self._third_party_packages[module_parts[0]]):
+        paths.append(os.path.join("stubs", package, module_path))
     for path_rel in paths:
       # Give precedence to MISSING_FILE
       if path_rel in self.missing:
@@ -284,84 +247,65 @@ class Typeshed:
     version_info = self._lookup_stdlib_version(module_parts)
     if version_info is None:
       return False
-    min_version, max_version, _ = version_info
+    min_version, max_version = version_info
     return (min_version <= version and
             (max_version is None or max_version >= version))
 
-  def get_typeshed_paths(self, python_version):
+  def get_typeshed_paths(self):
     """Gets the paths to typeshed's version-specific pyi files."""
-    major, _ = python_version
-    typeshed_subdirs = []
-    if major == 2:
-      typeshed_subdirs.append(os.path.join("stdlib", "@python2"))
-    typeshed_subdirs.append("stdlib")
+    typeshed_subdirs = ["stdlib"]
     for packages in self._third_party_packages.values():
-      for package, v in packages:
-        if v == major:
-          py2only_dir = os.path.join("stubs", package, "@python2")
-          if v == 2 and self._file_exists(py2only_dir):
-            typeshed_subdirs.append(os.path.join(py2only_dir))
-          else:
-            typeshed_subdirs.append(os.path.join("stubs", package))
+      for package in packages:
+        typeshed_subdirs.append(os.path.join("stubs", package))
     return [os.path.join(self._root, d) for d in typeshed_subdirs]
 
-  def get_pytd_paths(self, python_version):
+  def get_pytd_paths(self):
     """Gets the paths to pytype's version-specific pytd files."""
-    # TODO(mdemello): Should we add 2and3 here too and stop symlinking?
-    return [pytype_source_utils.get_full_path(d) for d in [
-        "stubs/builtins/%d" % python_version[0],
-        "stubs/stdlib/%d" % python_version[0]]]
+    return [pytype_source_utils.get_full_path(d)
+            for d in ("stubs/builtins", "stubs/stdlib")]
 
   def _list_modules(self, path, python_version):
     """Lists modules for _get_module_names_in_path."""
     for filename in self._list_files(path):
-      if filename.startswith("@python2/"):
-        # When Python 2 is requested, relative paths that already have the
-        # @python2/ prefix stripped are separately listed, so we should always
-        # skip paths that start with @python2/.
-        continue
-      if filename == "VERSIONS" or filename == "METADATA.toml":
+      if filename in ("VERSIONS", "METADATA.toml"):
         # stdlib/VERSIONS, stubs/{package}/METADATA.toml are metadata files.
         continue
       parts = path.split("/")
       if "stdlib" in parts:
-        if "@python2" in parts:
-          # stdlib/@python2/ stubs are Python 2-only.
-          if python_version[0] != 2:
-            continue
-        else:
-          # Check supported versions for stubs directly in stdlib/.
-          module_parts = os.path.splitext(filename)[0].split("/", 1)
-          if not self._is_module_in_typeshed(module_parts, python_version):
-            continue
+        # Check supported versions for stubs directly in stdlib/.
+        module_parts = os.path.splitext(filename)[0].split("/", 1)
+        if not self._is_module_in_typeshed(module_parts, python_version):
+          continue
       yield filename
 
-  def get_all_module_names(self, python_version):
-    """Get the names of all modules in typeshed or bundled with pytype."""
+  def _get_missing_modules(self):
+    """Gets module names from the `missing` list."""
     module_names = set()
-    for abspath in self.get_typeshed_paths(python_version):
-      relpath = abspath.rpartition("typeshed/")[-1]
-      module_names |= _get_module_names_in_path(
-          self._list_modules, relpath, python_version)
-    for abspath in self.get_pytd_paths(python_version):
-      relpath = abspath.rpartition("pytype/")[-1]
-      module_names |= _get_module_names_in_path(
-          lambda path, unused_ver: pytype_source_utils.list_pytype_files(path),
-          relpath, python_version)
-    # Also load modules not in typeshed, so that we have a dummy entry for them.
     for f in self.missing:
       parts = f.split("/")
-      if ("@python2" in parts) != (python_version[0] == 2):
-        continue
       if parts[0] == "stdlib":
         start_index = 1  # remove stdlib/ prefix
       else:
         assert parts[0] == "stubs"
         start_index = 2  # remove stubs/{package}/ prefix
-      if parts[start_index] == "@python2":
-        start_index += 1
       filename = "/".join(parts[start_index:])
       module_names.add(filename.replace("/", "."))
+    return module_names
+
+  def get_all_module_names(self, python_version):
+    """Get the names of all modules in typeshed or bundled with pytype."""
+    module_names = set()
+    for abspath in self.get_typeshed_paths():
+      relpath = abspath.rpartition("typeshed/")[-1]
+      module_names |= _get_module_names_in_path(
+          self._list_modules, relpath, python_version)
+    for abspath in self.get_pytd_paths():
+      relpath = abspath.rpartition("pytype/")[-1]
+      module_names |= _get_module_names_in_path(
+          lambda path, _: pytype_source_utils.list_pytype_files(path),
+          relpath, python_version)
+    # Also load modules not in typeshed, so that we have a dummy entry for them.
+    module_names |= self._get_missing_modules()
     assert "ctypes" in module_names  # sanity check
     return module_names
 
@@ -372,43 +316,15 @@ class Typeshed:
       if "#" in line:
         line = line[:line.index("#")]
       line = line.strip()
-      if line:
+      if line and "@python2" not in line:
         yield line
 
-  def blacklisted_modules(self, python_version):
+  def blacklisted_modules(self):
     """Return the blacklist, as a list of module names. E.g. ["x", "y.z"]."""
     for full_filename in self.read_blacklist():
-      filename = os.path.splitext(full_filename)[0]
+      filename, _ = os.path.splitext(full_filename)
       path = filename.split(os.path.sep)  # E.g. ["stdlib", "html", "parser"]
-      if python_version[0] in self.get_python_major_versions(full_filename):
-        yield module_utils.path_to_module_name(os.path.sep.join(path[2:]))
-
-  def get_python_major_versions(self, filename):
-    """Gets the Python major versions targeted by the given .pyi file."""
-    if os.path.sep + "@python2" + os.path.sep in filename:
-      return (2,)
-    parts = filename.split(os.path.sep)
-    if parts[0] == "stdlib":
-      version_info = self._lookup_stdlib_version(os.path.splitext(parts[1]))
-      assert version_info, f"{filename} missing from stdlib/VERSIONS"
-      min_version, _, use_python2 = version_info
-      # If use_python2 is true, we just use the stubs in @python2
-      if min_version >= (3, 0) or use_python2:
-        return (3,)
-      else:
-        return (2, 3)
-    else:
-      assert parts[0] == "stubs"
-      package, module = parts[1], os.path.splitext(parts[2])[0]
-      versions = []
-      for p, v in self._third_party_packages[module]:
-        if p != package or v == 2 and self._file_exists(
-            os.path.join("stubs", p, "@python2")):
-          # If a dedicated @python2 subdirectory exists, then the top-level
-          # stubs are Python 3-only.
-          continue
-        versions.append(v)
-      return tuple(versions)
+      yield module_utils.path_to_module_name(os.path.sep.join(path[2:]))
 
 
 _typeshed = None
