@@ -202,6 +202,8 @@ class SimpleFrame:
     self.f_globals = None
     self.current_opcode = opcode  # for memoization of unknowns
     self.node = node
+    self.substs = ()
+    self.func = None
 
 
 class Frame(utils.VirtualMachineWeakrefMixin):
